from django.urls import path
from . import views

urlpatterns = [
    path('signin', views.sign_in, name='signin'),
    path('signout', views.sign_out, name='signout'),
    path('callback', views.callback, name='callback'),
]


from django.apps import AppConfig
import ext_auth.default_settings as defaults
from django.conf import settings


class ExtAuthConfig(AppConfig):
    default_auto_field = 'django.db.models.BigAutoField'
    name = 'ext_auth'
    verbose_name = "Django External Authentication"

    def ready(self):
        for name in dir(defaults):
            if name.isupper() and not hasattr(settings, name):
                setattr(settings, name, getattr(defaults, name))
                print('setting ->', getattr(defaults, name), 'for ->', name)



EXT_AUTH_AAD_CLIENT_ID = None
EXT_AUTH_AAD_TENANT_ID = None
EXT_AUTH_AAD_AUTH_AUTHORITY = None
EXT_AUTH_AAD_CLIENT_SECRET = None
EXT_AUTH_AAD_REDIRECT_URI = '/auth/callback'
EXT_AUTH_AAD_AUTH_FLOW_KEY = "aad_auth_flow"
EXT_AUTH_AAD_ACCESS_TOKEN_KEY = "access_token"
EXT_AUTH_AAD_TOKEN_CACHE_KEY = 'aad_token_cache'
EXT_AUTH_POST_LOGIN_REDIRECT_URI = ''
EXT_AUTH_AAD_SCOPES = ["user.read", "user.read.all"]



from django.conf import settings
from django.http import HttpResponseRedirect
from django.urls import reverse
from django.contrib.auth import authenticate, login, logout
from django.contrib.auth.decorators import login_required
from ext_auth.backends.ext_auth import get_ext_auth_backend


def sign_in(request):
    backend = get_ext_auth_backend(request)
    http_response_redirect = backend.init_auth(request)

    if 'next' in request.GET:
        request.session['ext_auth_next'] = request.GET['next']

    # Redirect to ext auth signin
    return http_response_redirect


@login_required
def sign_out(request):
    logout(request)
    return HttpResponseRedirect(reverse("home"))


def callback(request):
    # callback with code received use it to authenticate the user
    user = authenticate(request)
    if user:
        login(request, user)

    if 'ext_auth_next' in request.session:
        return HttpResponseRedirect(request.session.pop('ext_auth_next'))

    return HttpResponseRedirect(settings.EXT_AUTH_POST_LOGIN_REDIRECT_URI)



from django.contrib.auth.models import User
from django.db import models
from ext_auth.choices import ExternalAuthType

class UserProfile(models.Model):

    user: User = models.OneToOneField(User, on_delete=models.CASCADE)
    display_name = models.CharField(max_length=100, null=True, blank=True)
    department = models.CharField(max_length=100, null=True, blank=True)
    ext_auth = models.IntegerField(
        blank=True, null=True, choices=ExternalAuthType.choices, default=None)

    def __str__(self):
        return self.user.username



from setuptools import setup, find_packages
__version__ = "1.0.2"

setup(
    name="django-auth-providers",
    version=__version__,
    description=(
        "django-auth-providers is a django app that lets you"
        " authenticate to external authentication providers"
    ),
    author="Petter Elenius Moe",
    author_email="pettermoe9530@gmail.com",
    url="https://github.com/pettermoe95/django-ext-auth/tree/main",
    packages=['ext_auth'] + ['ext_auth' + pkg for pkg in find_packages('ext_aut]h')],
)